Module: Tom::Config

Included in:
Tom
Defined in:
lib/tom/config.rb

Overview

Don't use this module directly - access these methods through Tom who does a extend Tom::Config

Instance Method Summary collapse

Instance Method Details

#configHash

Returns configuration.

Returns:

  • (Hash)

    configuration



8
9
10
# File 'lib/tom/config.rb', line 8

def config
  @config || default_config
end

#config=(config) ⇒ Hash

Returns configuration.

Parameters:

  • config (Hash)

    The configuration you want to set. Currently, only the :timeout key is read, and in it the :connect_timeout and the :inactivity_timeout keys can be set to an int value (seconds)

Returns:

  • (Hash)

    configuration



19
20
21
# File 'lib/tom/config.rb', line 19

def config=(config)
  @config = config
end